.. _recipe_asr.phonons:

asr.phonons
===========


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.phonons`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.phonons.calculate`
  - :py:func:`asr.phonons.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.phonons

or as a python module

.. code-block:: console

   $ python -m asr.phonons

Detailed description
--------------------
Phonon band structure and dynamical stability.

Steps
-----


asr.phonons@calculate
^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.phonons.calculate
   

asr.phonons
^^^^^^^^^^^
.. autofunction:: asr.phonons.main
   